#
# spec file for package hackrf
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   0
%define libname lib%{name}%{sover}
%define hackrf_group  hackrf
Name:           hackrf
Version:        2024.02.1
Release:        1.4
Summary:        Support programs for the open source SDR hardware
License:        GPL-2.0-only
Group:          Productivity/Hamradio/Other
URL:            https://greatscottgadgets.com/hackrf/
#Git-Clone:     https://github.com/greatscottgadgets/hackrf.git
Source:         https://github.com/greatscottgadgets/hackrf/releases/download/v%{version}/hackrf-%{version}.tar.xz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(udev)

%description
Tools for HackRF, an open source hardware project to build a Software
Defined Radio (SDR) peripheral.

%package -n %{libname}
Summary:        Driver for HackRF
Group:          Hardware/Other
Requires:       %{name}-udev

%description -n %{libname}
Library to run HackRF, an open source hardware project to build a Software
Defined Radio (SDR) peripheral.

%package udev
Summary:        Udev rules for HackRF
Group:          Hardware/Other
Requires(pre):  shadow

%description udev
Udev rules for HackRF.

%package devel
Summary:        Development files for HackRF
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description devel
Library headers for the hackrf driver.

%package firmware
Summary:        Firmware for the hackRF board
Group:          Hardware/Other
Requires:       %{name} = %{version}
BuildArch:      noarch

%description firmware
Firmare files for the hackRF board.

%prep
%setup -q -n %{name}-%{version}/host

%build
%cmake \
  -DINSTALL_UDEV_RULES=ON \
  -DUDEV_RULES_PATH=%{_udevrulesdir} \
  -DUDEV_RULES_GROUP=%{hackrf_group}
%make_build

%install
%cmake_install
rm %{buildroot}%{_libdir}/libhackrf.a

# install firmware
cd ..
mkdir -p %{buildroot}%{_datadir}/hackrf/firmware/
install -m644 firmware-bin/* %{buildroot}%{_datadir}/hackrf/firmware

%pre udev
getent group %{hackrf_group} >/dev/null || groupadd -r %{hackrf_group}

%post udev
%udev_rules_update

%postun udev
%udev_rules_update

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files
%license ../COPYING
%doc ../RELEASENOTES ../Readme.md
%{_bindir}/hackrf_biast
%{_bindir}/hackrf_clock
%{_bindir}/hackrf_cpldjtag
%{_bindir}/hackrf_debug
%{_bindir}/hackrf_info
%{_bindir}/hackrf_operacake
%{_bindir}/hackrf_spiflash
%{_bindir}/hackrf_sweep
%{_bindir}/hackrf_transfer

%files -n %{libname}
%{_libdir}/libhackrf.so.%{sover}*

%files udev
%{_udevrulesdir}/53-hackrf.rules

%files devel
%{_libdir}/libhackrf.so
%{_includedir}/libhackrf
%{_libdir}/pkgconfig/libhackrf.pc

%files firmware
%dir %{_datadir}/hackrf
%{_datadir}/hackrf/firmware

%changelog
* Wed Mar  6 2024 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 2024.02.1
  * A new utility, hackrf_biast, provides a way to control the "bias
    tee" antenna port power output on HackRF One. Thank you, Jonathan
    Suite (AI6AJ)!
  * Completely new and comprehensive libhackrf API documentation
    generated from source is now available in the release package.
    Thank you, László Baráth!
  * hackrf_sweep now supports more FFTW features including the
    ability to use a wisdom file. Thank you, Jonathan Suite (AI6AJ)!
  * HackRF One r10, the latest hardware revision, is based on r8,
    reverting most of the changes made in r9.
  * There have been many other enhancements and bug fixes. For a
    full list of changes, see the git log.
* Wed Feb 15 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 2023.01.1
  Note: You must also update firmware on your HackRF !
  * This release includes the hardware design and software support
  for HackRF One r9. The firmware in this release is compatible
  with all manufactured HackRF One hardware revisions from r1
  through r9. Firmware from prior releases is incompatible with
  HackRF One r9.
* Thu Sep 29 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 2022.09.1
  Note: You must also update firmware on your HackRF !
  Major changes:
  * Opera Cake, an antenna switching add-on board for HackRF One
    is fully supported.
  * A new user interface for rad1o provides status information
    during operation in HackRF mode.
  * Numerous performance, stability, and instrumentation
    improvements have been made to hackrf_transfer, hackrf_sweep,
    libhackrf, and firmware.
* Sat Mar 20 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2021.03.01
  Note: You must also update firmware on your HackRF !
  * CPLD bitstreams are now included in and loaded automatically
    by the firmware. There is no longer a need to update the CPLD
    separately.
  * The clock output (CLKOUT) is now turned off by default.
  * A new utility, hackrf_clock, provides a way to inspect and
    modify configuration of hardware clocks, including turning on
    and off CLKOUT.
  * The rad1o badge is now supported by firmware in this release.
    Firmware from the HackRF release/repository is different than
    the original CCCamp firmware and only supports operation as a
    USB SDR peripheral.
  * When using a HackRF One with a PortaPack in "HackRF Mode"
    (operating as a USB peripheral), the PortaPack display now
    indicates operational status and settings.
  * There have been many more enhancements and bug fixes.
* Mon Jan 29 2018 mardnh@gmx.de
- Update to version 2018.01.01
  * This is a firmware maintenance release that improves
    reliability of HackRF One when booting from the DFU bootloader.
- Run spec-cleaner
* Fri Nov  3 2017 jengelh@inai.de
- Description and group updates.
* Sun Apr 23 2017 mardnh@gmx.de
- Update group handling
* Sat Apr 15 2017 mardnh@gmx.de
- Use proper cmake options
- Package firmware
* Wed Mar  8 2017 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
* Fri Feb 17 2017 frede@b1-systems.de
- update to version 2017.02.1
* Thu Aug 13 2015 frede@b1-systems.de
- update to version 2015.07.2
- add group hackrf for udev rules
- add patch for typo in rad1o udev rule
* Fri Sep  5 2014 dl8fcl@darc.de
- update to version 2014.08.1
* Sun Nov  3 2013 lnt-sysadmin@lists.lrz.de
- Changes to spec file:
  * Update udev paths for openSUSE 13.1 and ensure udev rules are
    updated when package is installed / updated / uninstalled.
  * Define %%libname to ease reuse of %%post(un) macros
* Sat Nov  2 2013 dl8fcl@darc.de
- import into build service
